podgen.Category — PodGen Documentation

# podgen.Category

class `podgen.` `Category`(category, subcategory=None)

  Immutable class representing an iTunes category.

  See https://help.apple.com/itc/podcasts_connect/#/itc9267a2f12 for an overview of the available categories and their subcategories.

  Note

  The categories are case-insensitive, and you may escape ampersands. The category and subcategory will end up properly capitalized and with unescaped ampersands.

  Example:

      >>> from podgen import Category
      >>> c = Category("Music")
      >>> c.category
      Music
      >>> c.subcategory
      None
      >>>
      >>> d = Category("games &amp; hobbies", "Video games")
      >>> d.category
      Games & Hobbies
      >>> d.subcategory
      Video Games

  property `category`

    The category represented by this object. Read-only.

    Type

      `str`

  property `subcategory`

    The subcategory this object represents. Read-only.

    Type

      `str`